[Introduction](README.md)

______________________________________________________________________

# Overview

- [Environments](envs/index.md)
  - [Manipulation](envs/manipulation.md)
  - [Mobile Robotics](envs/mobile_robotics.md)
  - [Mobile Manipulation](envs/mobile_manipulation.md)
- [Robots](robots/index.md)
  - [Manipulators](robots/manipulators.md)
  - [Mobile Robots](robots/mobile_robots.md)
  - [Mobile Manipulators](robots/mobile_manipulators.md)
- [Integrations & Interfaces](integrations/index.md)
  - [ROS 2 & Space ROS](integrations/ros2.md)
  - [Reinforcement Learning](integrations/reinforcement_learning.md)
  - [Imitation Learning](<>)
  - [Extended Reality](<>)

______________________________________________________________________

# Getting Started

- [System Requirements](getting_started/requirements.md)
- [Installation](getting_started/install.md)
  - [Native](getting_started/install_native.md)
  - [Docker (Recommended)](getting_started/install_docker.md)
  - [Apptainer/Singularity](getting_started/install_apptainer.md)
- [Basic Usage](getting_started/basic_usage.md)
- [Workflows](workflows/index.md)
  - [ROS 2](workflows/ros2.md)
  - [Reinforcement Learning](workflows/reinforcement_learning.md)
  - [Imitation Learning](<>)
  - [Sim-to-Real](<>)

# Configuration

- [Environment Configuration](config/env_cfg.md)
  - [Parallelism](config/parallelism.md)
  - [Domain](config/domain.md)
  - [Robot](config/robot.md)
  - [Particles](config/particles.md)
- [Agent Configuration](config/agent_cfg.md)

# Reference

- [Command Line Interface](reference/cli.md)
  - [List Assets and Tasks](reference/cli_ls.md)
  - [Zero Agent](reference/cli_agent_zero.md)
  - [Random Agent](reference/cli_agent_rand.md)
  - [Teleoperate Agent](reference/cli_agent_teleop.md)
  - [ROS 2 Agent](reference/cli_agent_ros.md)
  - [Train Agent](reference/cli_agent_train.md)
  - [Evaluate Agent](reference/cli_agent_eval.md)
  - [Collect Demonstrations](<>)
  - [Learn from Demonstrations](<>)
  - [Enter Python REPL](reference/cli_repl.md)
- [Graphical User Interface](reference/gui.md)

______________________________________________________________________

# Development

- [IDE Configuration](development/ide_cfg.md)
- [Dev Container](development/devcontainer.md)
- [Testing](development/testing.md)
- [Documentation](development/documentation.md)
- [Utilities](development/utilities.md)
  - [Update Assets](development/update_assets.md)
  - [Clean Cache](development/clean_cache.md)

# Contributing

- [New Assets](contributing/new_assets.md)
- [New Tasks](contributing/new_tasks.md)

______________________________________________________________________

[Attributions](misc/attributions.md)
[Contributors](misc/contributors.md)
[Citation](misc/citation.md)
[Community](misc/community.md)
[Troubleshooting](misc/troubleshooting.md)
